==> v1.1.6.tar.gz: twitch-cli-1.1.6/internal/events/types/ban/ban.go <==
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
package ban

import (
	"encoding/json"
	"time"

	"github.com/twitchdev/twitch-cli/internal/events"
	"github.com/twitchdev/twitch-cli/internal/models"
	"github.com/twitchdev/twitch-cli/internal/util"
)

var transportsSupported = map[string]bool{
	models.TransportEventSub: true,
}

var triggerSupported = []string{"ban", "unban"}

var triggerMapping = map[string]map[string]string{
	models.TransportEventSub: {
		"ban":   "channel.ban",
		"unban": "channel.unban",
	},
}

type Event struct{}

func (e Event) GenerateEvent(params events.MockEventParameters) (events.MockEventResponse, error) {
	var event []byte
	var err error

	switch params.Transport {
	case models.TransportEventSub:
		e := models.BanEventSubEvent{
			UserID:               params.FromUserID,
			UserLogin:            params.FromUserName,
			UserName:             params.FromUserName,
			BroadcasterUserID:    params.ToUserID,
			BroadcasterUserLogin: params.ToUserName,
			BroadcasterUserName:  params.ToUserName,
			ModeratorUserId:      util.RandomUserID(),
			ModeratorUserLogin:   "CLIModerator",
			ModeratorUserName:    "CLIModerator",
		}

		if params.Trigger == "ban" {
			reason := "This is a test event"
			endsAt := util.GetTimestamp().Format(time.RFC3339Nano)
			e.Reason = &reason
			e.EndsAt = &endsAt
			e.IsPermanent = &params.IsPermanent
		}

		body := *&models.EventsubResponse{
			Subscription: models.EventsubSubscription{
				ID:      params.ID,
				Status:  "enabled",
				Type:    triggerMapping[params.Transport][params.Trigger],
				Version: "1",
				Condition: models.EventsubCondition{
					BroadcasterUserID: params.ToUserID,
				},
				Transport: models.EventsubTransport{
					Method:   "webhook",
					Callback: "null",
				},
				Cost:      0,
				CreatedAt: util.GetTimestamp().Format(time.RFC3339Nano),
			},
			Event: e,
		}

		event, err = json.Marshal(body)
		if err != nil {
			return events.MockEventResponse{}, err
		}
	default:
		return events.MockEventResponse{}, nil
	}

	return events.MockEventResponse{
		ID:       params.ID,
		JSON:     event,
		FromUser: params.FromUserID,
		ToUser:   params.ToUserID,
	}, nil
}

func (e Event) ValidTransport(t string) bool {
	return transportsSupported[t]
}

func (e Event) ValidTrigger(t string) bool {
	for _, ts := range triggerSupported {
		if ts == t {
			return true
		}
	}
	return false
}

func (e Event) GetTopic(transport string, trigger string) string {
	return triggerMapping[transport][trigger]
}
func (e Event) GetEventSubAlias(t string) string {
	// check for aliases
	for trigger, topic := range triggerMapping[models.TransportEventSub] {
		if topic == t {
			return trigger
		}
	}
	return ""
}

==> v1.1.14.tar.gz: twitch-cli-1.1.14/internal/events/types/ban/ban.go <==
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
package ban

import (
	"encoding/json"
	"strings"
	"time"

	"github.com/twitchdev/twitch-cli/internal/events"
	"github.com/twitchdev/twitch-cli/internal/models"
	"github.com/twitchdev/twitch-cli/internal/util"
)

var transportsSupported = map[string]bool{
	models.TransportEventSub: true,
}

var triggerSupported = []string{"ban", "unban"}

var triggerMapping = map[string]map[string]string{
	models.TransportEventSub: {
		"ban":   "channel.ban",
		"unban": "channel.unban",
	},
}

type Event struct{}

func (e Event) GenerateEvent(params events.MockEventParameters) (events.MockEventResponse, error) {
	var event []byte
	var err error

	switch params.Transport {
	case models.TransportEventSub:
		ban := models.BanEventSubEvent{
			UserID:               params.FromUserID,
			UserLogin:            params.FromUserName,
			UserName:             params.FromUserName,
			BroadcasterUserID:    params.ToUserID,
			BroadcasterUserLogin: params.ToUserName,
			BroadcasterUserName:  params.ToUserName,
			ModeratorUserId:      util.RandomUserID(),
			ModeratorUserLogin:   "CLIModerator",
			ModeratorUserName:    "CLIModerator",
		}

		if params.Trigger == "ban" {
			reason := "This is a test event"
			bannedAt := params.Timestamp
			var endsAt *string = nil

			if !params.IsPermanent {
				// Timeout uses channel.ban as well, which is why IsPermanent exists
				// Set ends_at to be 3 minutes in the future
				tNow, _ := time.Parse(time.RFC3339Nano, params.Timestamp)
				tLater := tNow.Add(time.Minute * 10).Format(time.RFC3339Nano)
				endsAt = &tLater
			}

			ban.Reason = &reason
			ban.BannedAt = &bannedAt
			ban.EndsAt = endsAt
			ban.IsPermanent = &params.IsPermanent
		}

		body := *&models.EventsubResponse{
			Subscription: models.EventsubSubscription{
				ID:      params.ID,
				Status:  params.SubscriptionStatus,
				Type:    triggerMapping[params.Transport][params.Trigger],
				Version: e.SubscriptionVersion(),
				Condition: models.EventsubCondition{
					BroadcasterUserID: params.ToUserID,
				},
				Transport: models.EventsubTransport{
					Method:   "webhook",
					Callback: "null",
				},
				Cost:      0,
				CreatedAt: params.Timestamp,
			},
			Event: ban,
		}

		event, err = json.Marshal(body)
		if err != nil {
			return events.MockEventResponse{}, err
		}

		// Delete event info if Subscription.Status is not set to "enabled"
		if !strings.EqualFold(params.SubscriptionStatus, "enabled") {
			var i interface{}
			if err := json.Unmarshal([]byte(event), &i); err != nil {
				return events.MockEventResponse{}, err
			}
			if m, ok := i.(map[string]interface{}); ok {
				delete(m, "event") // Matches JSON key defined in body variable above
			}

			event, err = json.Marshal(i)
			if err != nil {
				return events.MockEventResponse{}, err
			}
		}
	default:
		return events.MockEventResponse{}, nil
	}

	return events.MockEventResponse{
		ID:       params.ID,
		JSON:     event,
		FromUser: params.FromUserID,
		ToUser:   params.ToUserID,
	}, nil
}

func (e Event) ValidTransport(t string) bool {
	return transportsSupported[t]
}

func (e Event) ValidTrigger(t string) bool {
	for _, ts := range triggerSupported {
		if ts == t {
			return true
		}
	}
	return false
}

func (e Event) GetTopic(transport string, trigger string) string {
	return triggerMapping[transport][trigger]
}
func (e Event) GetEventSubAlias(t string) string {
	// check for aliases
	for trigger, topic := range triggerMapping[models.TransportEventSub] {
		if topic == t {
			return trigger
		}
	}
	return ""
}

func (e Event) SubscriptionVersion() string {
	return "1"
}
